/***************************************************************
 * File: Races.c                                               *
 * Usage: Source-file for race-specific code                   *
 * Author: Henrik Stuart <hstuart@geocities.com>               *
 **************************************************************/

#include "conf.h"
#include "sysdep.h"

#include "structs.h"
#include "db.h"
#include "utils.h"
#include "spells.h"
#include "interpreter.h"

/* Local functions */
const char *race_abbrevs[];
const char *pc_race_types[];
const char *race_menu;
int parse_race(char arg);
long find_race_bitvector(char arg);
int invalid_race(struct char_data *ch, struct obj_data *obj);

const char *race_abbrevs[] = {
  "Hum",
  "Dwa",
  "Elf",
  "Hob",
  "\n"
};

const char *pc_race_types[] = {
  "Human",
  "Dwarf",
  "Elf",
  "Hobbit",
  "\n"
};

const char *race_menu =
"\r\n"
"Select a race:\r\n"
"  1) Human\r\n"
"  2) Dwarf\r\n"
"  3) Elf\r\n"
"  4) Hobbit\r\n";

int parse_race(char arg) {

  switch (arg) {
    case '1': return RACE_HUMAN;
    case '2': return RACE_DWARF;
    case '3': return RACE_ELF;
    case '4': return RACE_HOBBIT;
    default: return RACE_UNDEFINED;
  }
}

long find_race_bitvector(char arg) {
  
  switch (arg) {
    case '1': return (1 << RACE_HUMAN);
    case '2': return (1 << RACE_DWARF);
    case '3': return (1 << RACE_ELF);
    case '4': return (1 << RACE_HOBBIT);
    default: return 0;
  }
}

int invalid_race(struct char_data *ch, struct obj_data *obj) {
  if ((IS_OBJ_STAT(obj, ITEM_ANTI_HUMAN) && IS_HUMAN(ch)) ||
      (IS_OBJ_STAT(obj, ITEM_ANTI_DWARF) && IS_DWARF(ch)) ||
      (IS_OBJ_STAT(obj, ITEM_ANTI_ELF) && IS_ELF(ch)) ||
      (IS_OBJ_STAT(obj, ITEM_ANTI_HOBBIT) && IS_HOBBIT(ch)))
    return 1;
  else
    return 0;
}
